@@ -29,7 +29,6 @@ class MainForm(QtGui.QMainWindow):
         x = (desktop.width() - self.window().width()) / 2
         y = (desktop.height() - self.window().height()) / 3
         
-        print x, y
         self.move(x, y)
         
         
@@ -80,7 +79,6 @@ class MainForm(QtGui.QMainWindow):
     def keyPressEvent(self, event):
         
         key = event.key()
-        print key
         
         if event.modifiers() == QtCore.Qt.NoModifier and key == QtCore.Qt.Key_Escape:
             self.close()
